#' schtools: Schloss Lab Tools for Reproducible Microbiome Research
#'
#' A collection of useful functions and example code created and used by the
#' Schloss Lab for reproducible microbiome research. Perform common tasks like
#' read files created by [mothur](https://mothur.org/), tidy up your microbiome
#' data, and format rmarkdown documents for publication. See the
#' [website](http://www.schlosslab.org/schtools/) for more information,
#' documentation, and examples.
#'
#' @keywords internal
"_PACKAGE"
